// 统一请求路径前缀在libs/axios.js中修改
import { getRequest, postRequest, putRequest, getNoAuthRequest, postNoAuthRequest } from '@/libs/axios';


// 获取菜单
export const getMenuList = "/adminapi/permission/menu/userRoleMenuList"

// 登陆
export const login = (params) => {
    return postNoAuthRequest('/auth/login', params)
}
// 获取用户登录信息
export const userInfo = (params) => {
    return getRequest('/user/info', params)
}

//登出
export const logout = (params) => {
    return getRequest('/auth/logout', params)
}

// 个人中心修改密码
export const changePass = (params) => {
    return postRequest('/auth/resetPassword', params)
}


// 获取用户数据 多条件
export const getUserListData = (params) => {
    return getRequest('/user/listByPage', params)
}
// 通过用户名搜索
export const searchUserByName = (username, params) => {
    return getRequest('/user/searchByName/'+username, params)
}
// 获取全部用户数据
export const getAllUserData = (params) => {
    return getRequest('/user/getAll', params)
}

// 添加用户
export const addUser = (params) => {
    return postRequest('/user/add', params)
}
// 编辑用户
export const editUser = (params) => {
    return postRequest('/user/edit', params)
}
// 启用用户
export const enableUser = (id, params) => {
    return postRequest(`/user/enable/${id}`, params)
}
// 禁用用户
export const disableUser = (id, params) => {
    return postRequest(`/user/disable/${id}`, params)
}
// 删除用户
export const deleteUser = (params) => {
    return postRequest('/user/delByIds', params)
}
// 重置用户密码
export const resetUserPass = (params) => {
    return postRequest('/user/resetPass', params)
}

/*=================== 角色相关接口   开始================================ */


// 获取全部角色数据
export const getAllRoleList = (params) => {
    return getRequest('/permission/role/getAllList', params)
}
// 分页获取角色数据
export const getRoleList = (params) => {
    return getRequest('/permission/role/getAllByPage', params)
}
// 添加角色
export const addRole = (params) => {
    return postRequest('/permission/role/add', params)
}
// 编辑角色
export const editRole = (params) => {
    return postRequest('/permission/role/edit', params)
}

// 设为或取消注册角色
export const setDefaultRole = (params) => {
    return postRequest('/permission/role/setDefault', params)
}
// 分配角色权限
export const editRolePerm = (params) => {
    return postRequest('/permission/role/editRolePermission', params)
}

// 删除角色
export const deleteRole = (params) => {
    return postRequest('/permission/role/delByIds', params)
}


/*=================== 角色相关接口   结束================================ */


/*=================== 菜单相关接口   开始================================ */

// 添加菜单权限
export const addMenus = (params) => {
    return postRequest('/permission/menu/add', params)
}
// 编辑菜单权限
export const editMenus = (params) => {
    return postRequest('/permission/menu/edit', params)
}
// 删除菜单权限
export const deleteMenus = (params) => {
    return postRequest('/permission/menu/del', params)
}
// 添加权限
export const addSubMenus = (params) => {
    return postRequest('/permission/menu/subAdd', params)
}

// 获取全部权限数据
export const getAllPermissionList = (params) => {
    return getRequest('/permission/menu/all', params)
}

/*=================== 菜单相关接口   结束================================ */

/*=================== 工具类相关接口   开始================================ */
// 获取白化采购订单 
export const getBhPordersListData = (params) => {
    return getRequest('/tools/bh/searchBhPorders', params)
}

export const editBhOrders = (params) => {
    return postRequest('/tools/bh/editBhPorders', params)
}

export const addSorderRefundTask = (params) => {
    return postRequest('/tools/bh/addSorderRefundTask', params)
}

export const getBhSordersDataDetail = (params) => {
    return postRequest('/tools/bh/getBhSordersDetail', params)
}

export const getBhSordersRefundTask = (params) => {
    return getRequest('/tools/bh/getBhSorderRefundTask', params)
}

export const execBhSordersRefundTask = (params) => {
    return postRequest('/tools/bh/execBhSorderRefundTask', params)
}

/*=================== 工具类相关接口   结束================================ */


// 加载数据
export const loadPermission = (id, params) => {
    return getRequest(`/permission/getByParentId/${id}`, params)
}
// 添加权限
export const addPermission = (params) => {
    return postRequest('/permission/add', params)
}
// 编辑权限
export const editPermission = (params) => {
    return postRequest('/permission/edit', params)
}
// 删除权限
export const deletePermission = (params) => {
    return postRequest('/permission/delByIds', params)
}
// 搜索权限
export const searchPermission = (params) => {
    return getRequest('/permission/search', params)
}



// 获取全部字典
export const getAllDictList = (params) => {
    return getRequest('/dict/getAll', params)
}
// 添加字典
export const addDict = (params) => {
    return postRequest('/dict/add', params)
}
// 编辑字典
export const editDict = (params) => {
    return postRequest('/dict/edit', params)
}
// 删除字典
export const deleteDict = (params) => {
    return postRequest('/dict/delByIds', params)
}
// 搜索字典
export const searchDict = (params) => {
    return getRequest('/dict/search', params)
}
// 获取全部字典数据
export const getAllDictDataList = (params) => {
    return getRequest('/dictData/getByCondition', params)
}
// 添加字典数据
export const addDictData = (params) => {
    return postRequest('/dictData/add', params)
}
// 编辑字典数据
export const editDictData = (params) => {
    return postRequest('/dictData/edit', params)
}
// 删除字典数据
export const deleteData = (params) => {
    return postRequest('/dictData/delByIds', params)
}
// 通过类型获取字典数据
export const getDictDataByType = (type, params) => {
    return getRequest(`/permission/dictData/${type}`, params)
}


// 分页获取日志数据
export const getLogListData = (params) => {
    return getRequest('/log/getAllByPage', params)
}
// 删除日志
export const deleteLog = (params) => {
    return postRequest('/log/delByIds', params)
}
// 清空日志
export const deleteAllLog = (params) => {
    return postRequest('/log/delAll', params)
}

// base64上传
export const base64Upload = (params) => {
    return postRequest('/upload/file', params)
}